@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 
 from django.shortcuts import redirect, render_to_response
 from django.contrib import messages
+from django.contrib.admin import site
 from django.template import RequestContext
 from django.core.cache import cache, get_cache
 from django.conf import settings
@@ -63,6 +64,16 @@ def _get_cache_slabs(server_name=None):
     return server_info
 
 
+def _context_data(data):
+    """
+    Add admin global context, for compability with Django 1.7
+    """
+    try:
+        return dict(site.each_context().items() + data.items())
+    except AttributeError:
+        return data
+
+
 def server_status(request):
     """
     Return the status of all servers.
@@ -78,12 +89,12 @@ def dashboard(request):
     """
     Show the dashboard.
     """
-    data = {
+    data = _context_data({
         'title': _('Memcache Dashboard'),
         'cache_stats': _get_cache_stats(),
         'can_get_slabs': hasattr(mc_client, 'get_slabs'),
         'REFRESH_RATE': SETTINGS['REFRESH_RATE'],
-    }
+    })
     return render_to_response('memcache_admin/dashboard.html', data, RequestContext(request))
 
 
@@ -92,10 +103,10 @@ def stats(request, server_name):
     Show server tatistics.
     """
     server_name = server_name.strip('/')
-    data = {
+    data = _context_data({
         'title': _('Memcache Statistics for %s') % server_name,
         'cache_stats': _get_cache_stats(server_name),
-    }
+    })
     return render_to_response('memcache_admin/stats.html', data, RequestContext(request))
 
 
@@ -103,10 +114,10 @@ def slabs(request, server_name):
     """
     Show server slabs.
     """
-    data = {
+    data = _context_data({
         'title': _('Memcache Slabs for %s') % server_name,
         'cache_slabs': _get_cache_slabs(server_name),
-    }
+    })
     return render_to_response('memcache_admin/slabs.html', data, RequestContext(request))
 
 
